@@ -5,9 +5,9 @@ def make():
     os.system('git clone https://github.com/WWEMGamer2/OS-Folders.git')
     i = input('[./OS/config.py] What is your OS name? ')
     print("Formatting...")
-    os.system(f'mv ./OS ./{i}')
+    os.system(f'mv ./OS-Folders ./{i}')
     i = input('[./OS/config.py] Where is your mandatory folder? ')
-    for f in os.listdir('./'):
+    for f in os.listdir(f'./{i}'):
         if i == f:
             print("Found the required folder.")
             print("Formatting...")
